@@ -56,7 +56,7 @@
 #' The default \code{threshold} is often arbitrarily set to some deviation (in
 #' terms of SD or MAD) from the mean (or median) of the Mahalanobis distance.
 #' However, as the Mahalanobis distance can be approximated by a Chi squared
-#' distribution (Rousseeuw & Van Zomeren, 1990), we can use the the alpha quantile
+#' distribution (Rousseeuw & Van Zomeren, 1990), we can use the alpha quantile
 #' of the chi-square distribution with k degrees of freedom (k being the number of
 #' columns). By default, the alpha threshold is set to 0.025 (corresponding to the
 #' 2.5\% most extreme observations; Cabana, 2019). This criterion is a natural extension of the
@@ -241,7 +241,7 @@ check_outliers.default <- function(x, method = c("cook", "pareto"), threshold =
 
 #' @rdname check_outliers
 #' @export
-check_outliers.numeric <- function(x, method = "zscore", threshold = NULL, ...){
+check_outliers.numeric <- function(x, method = "zscore", threshold = NULL, ...) {
   check_outliers(as.data.frame(x), method = method, threshold = threshold, ...)
 }
 
@@ -325,7 +325,7 @@ check_outliers.data.frame <- function(x, method = "mahalanobis", threshold = NUL
   for (i in names(out[sapply(out, is.data.frame)])) {
     df <- cbind(df, out[[i]])
   }
-  df$Obs <- NULL  # Remove temp column
+  df$Obs <- NULL # Remove temp column
 
 
   # Composite outlier score
@@ -346,12 +346,12 @@ check_outliers.data.frame <- function(x, method = "mahalanobis", threshold = NUL
 
 
 #' @export
-as.data.frame.check_outliers <- function(x, ...){
+as.data.frame.check_outliers <- function(x, ...) {
   attributes(x)$data
 }
 
 #' @export
-as.numeric.check_outliers <- function(x, ...){
+as.numeric.check_outliers <- function(x, ...) {
   attributes(x)$data$Outlier
 }
 
@@ -391,9 +391,9 @@ as.numeric.check_outliers <- function(x, ...){
 
 .check_outliers_zscore <- function(x, threshold = stats::qnorm(p = 1 - 0.025), robust = TRUE, method = "max") {
   # Standardize
-  if(robust == FALSE){
+  if (robust == FALSE) {
     d <- abs(as.data.frame(sapply(x, function(x) (x - mean(x, na.rm = TRUE)) / sd(x, na.rm = TRUE))))
-  } else{
+  } else {
     d <- abs(as.data.frame(sapply(x, function(x) (x - median(x, na.rm = TRUE)) / mad(x, na.rm = TRUE))))
   }
 
@@ -415,15 +415,13 @@ as.numeric.check_outliers <- function(x, ...){
 
 #' @importFrom stats IQR quantile
 .check_outliers_iqr <- function(x, threshold = 1.5, method = "tukey") {
-
   d <- data.frame(Obs = 1:nrow(as.data.frame(x)))
-  for(col in 1:ncol(as.data.frame(x))){
-
+  for (col in 1:ncol(as.data.frame(x))) {
     v <- x[, col]
 
-    if(method == "tukey"){
+    if (method == "tukey") {
       iqr <- stats::quantile(v, 0.75, na.rm = TRUE) - stats::quantile(v, 0.25, na.rm = TRUE)
-    } else{
+    } else {
       iqr <- stats::IQR(v, na.rm = TRUE)
     }
 
@@ -431,13 +429,18 @@ as.numeric.check_outliers <- function(x, ...){
     upper <- stats::quantile(v, 0.75, na.rm = TRUE) + (iqr * threshold)
 
     d[names(as.data.frame(x))[col]] <- ifelse(v > upper, 1,
-                                                ifelse(v < lower, 1, 0))
+      ifelse(v < lower, 1, 0)
+    )
   }
   d$Obs <- NULL
 
   out <- data.frame(Obs = 1:nrow(as.data.frame(d)))
-  out$Distance_IQR <- sapply(as.data.frame(t(d)), function(x) {ifelse(all(is.na(x)), NA, mean(x))})
-  out$Outlier_IQR <- sapply(as.data.frame(t(d)), function(x) {ifelse(all(is.na(x)), NA, max(x))})
+  out$Distance_IQR <- sapply(as.data.frame(t(d)), function(x) {
+    ifelse(all(is.na(x)), NA, mean(x))
+  })
+  out$Outlier_IQR <- sapply(as.data.frame(t(d)), function(x) {
+    ifelse(all(is.na(x)), NA, max(x))
+  })
 
   out$Obs <- NULL
   list(
@@ -473,7 +476,7 @@ as.numeric.check_outliers <- function(x, ...){
 
   # Install packages
   if (!requireNamespace("loo", quietly = TRUE)) {
-    stop("Package `loo` needed for this function to work. Please install it.", call. = FALSE)
+    stop("Package `loo` required for this function to work. Please install it by running `install.packages('loo')`.", call. = FALSE)
   }
 
   # Compute
@@ -519,7 +522,7 @@ as.numeric.check_outliers <- function(x, ...){
 
   # Install packages
   if (!requireNamespace("bigutilsr", quietly = TRUE)) {
-    stop("Package `bigutilsr` needed for this function to work. Please install it.", call. = FALSE)
+    stop("Package `bigutilsr` required for this function to work. Please install it by running `install.packages('bigutilsr')`.", call. = FALSE)
   }
 
 
@@ -543,7 +546,7 @@ as.numeric.check_outliers <- function(x, ...){
 
   # Install packages
   if (!requireNamespace("MASS", quietly = TRUE)) {
-    stop("Package `MASS` needed for this function to work. Please install it.", call. = FALSE)
+    stop("Package `MASS` required for this function to work. Please install it by running `install.packages('MASS')`.", call. = FALSE)
   }
 
   # Compute
@@ -568,10 +571,10 @@ as.numeric.check_outliers <- function(x, ...){
 
   # Install packages
   if (!requireNamespace("ICS", quietly = TRUE)) {
-    stop("Package `ICS` needed for this function to work. Please install it.", call. = FALSE)
+    stop("Package `ICS` required for this function to work. Please install it by running `install.packages('ICS')`.", call. = FALSE)
   }
   if (!requireNamespace("ICSOutlier", quietly = TRUE)) {
-    stop("Package `ICSOutlier` needed for this function to work. Please install it.", call. = FALSE)
+    stop("Package `ICSOutlier` required for this function to work. Please install it by running `install.packages('ICSOutlier')`.", call. = FALSE)
   }
 
   # Get n cores
@@ -583,13 +586,14 @@ as.numeric.check_outliers <- function(x, ...){
 
   # Run algorithm
   # Try
-  outliers <- tryCatch({
-    ics <- ICS::ics2(x)
-    ICSOutlier::ics.outlier(object = ics, ncores = n_cores, level.dist = threshold, ...)
-  },
-  error = function(e) {
-    NULL
-  }
+  outliers <- tryCatch(
+    {
+      ics <- ICS::ics2(x)
+      ICSOutlier::ics.outlier(object = ics, ncores = n_cores, level.dist = threshold, ...)
+    },
+    error = function(e) {
+      NULL
+    }
   )
 
   if (is.null(outliers)) {
@@ -622,18 +626,18 @@ as.numeric.check_outliers <- function(x, ...){
 
   # Install packages
   if (!requireNamespace("dbscan", quietly = TRUE)) {
-    stop("Package `dbscan` needed for this function to work. Please install it.", call. = FALSE)
+    stop("Package `dbscan` required for this function to work. Please install it by running `install.packages('dbscan')`.", call. = FALSE)
   }
 
   # Compute
   rez <- dbscan::optics(x, minPts = threshold)
-  rez <- dbscan::extractXi(rez, xi = 0.05)  # TODO: find automatic way of setting xi
+  rez <- dbscan::extractXi(rez, xi = 0.05) # TODO: find automatic way of setting xi
 
   out$Distance_OPTICS <- rez$coredist
   # Filter
-  if(is.null(rez$cluster)){
+  if (is.null(rez$cluster)) {
     out$Outlier_OPTICS <- 0
-  } else{
+  } else {
     out$Outlier_OPTICS <- as.numeric(rez$cluster == 0)
   }
 
@@ -646,19 +650,28 @@ as.numeric.check_outliers <- function(x, ...){
 }
 
 
-
+#' @importFrom utils packageVersion
 #' @importFrom stats median qnorm mad sd
 .check_outliers_iforest <- function(x, threshold = 0.025) {
   out <- data.frame(Obs = 1:nrow(x))
 
   # Install packages
   if (!requireNamespace("solitude", quietly = TRUE)) {
-    stop("Package `solitude` needed for this function to work. Please install it.", call. = FALSE)
+    stop("Package `solitude` required for this function to work. Please install it by running `install.packages('solitude')`.", call. = FALSE)
   }
 
   # Compute
-  iforest <- solitude::isolationForest(x)
-  out$Distance_iforest <- predict(iforest, x, type = "anomaly_score")
+  if (utils::packageVersion("solitude") < "0.2.0") {
+    iforest <- solitude::isolationForest(x)
+    out$Distance_iforest <- predict(iforest, x, type = "anomaly_score")
+  } else if (utils::packageVersion("solitude") == "0.2.0"){
+    stop("Must update package `solitude` (above version 0.2.0). Please run `install.packages('solitude')`.", call. = FALSE)
+  } else{
+    iforest <- solitude::isolationForest$new(sample_size = nrow(x))
+    suppressMessages(iforest$fit(x))
+    out$Distance_iforest <- iforest$scores$anomaly_score
+  }
+
 
   # Threshold
   cutoff <- stats::median(out$Distance_iforest) + stats::qnorm(1 - threshold) * stats::mad(out$Distance_iforest)
@@ -679,7 +692,7 @@ as.numeric.check_outliers <- function(x, ...){
 
   # Install packages
   if (!requireNamespace("dbscan", quietly = TRUE)) {
-    stop("Package `dbscan` needed for this function to work. Please install it.", call. = FALSE)
+    stop("Package `dbscan` required for this function to work. Please install it by running `install.packages('dbscan')`.", call. = FALSE)
   }
 
 
