@@ -59,17 +59,18 @@
 #' )
 #'
 #' check_singularity(model)
-#'
 #' @export
 check_singularity <- function(x, tolerance = 1e-5, ...) {
   UseMethod("check_singularity")
 }
 
 
+
 #' @export
 check_singularity.merMod <- function(x, tolerance = 1e-5, ...) {
-  if (!requireNamespace("lme4", quietly = TRUE))
+  if (!requireNamespace("lme4", quietly = TRUE)) {
     stop("Package `lme4` needed for this function to work. Please install it.")
+  }
 
   theta <- lme4::getME(x, "theta")
   # diagonal elements are identifiable because they are fitted
@@ -78,48 +79,71 @@ check_singularity.merMod <- function(x, tolerance = 1e-5, ...) {
   any(abs(theta[diag.element]) < tolerance)
 }
 
+#' @export
+check_singularity.rlmerMod <- check_singularity.merMod
+
+
+
 #' @export
 check_singularity.glmmTMB <- function(x, tolerance = 1e-5, ...) {
-  if (!requireNamespace("lme4", quietly = TRUE))
+  if (!requireNamespace("lme4", quietly = TRUE)) {
     stop("Package `lme4` needed for this function to work. Please install it.")
+  }
 
   vc <- .collapse_cond(lme4::VarCorr(x))
   any(sapply(vc, function(.x) any(abs(diag(.x)) < tolerance)))
 }
 
+#' @export
+check_singularity.glmmadmb <- check_singularity.glmmTMB
+
+
+
 #' @export
 check_singularity.clmm <- function(x, tolerance = 1e-5, ...) {
-  if (!requireNamespace("ordinal", quietly = TRUE))
+  if (!requireNamespace("ordinal", quietly = TRUE)) {
     stop("Package `ordinal` needed for this function to work. Please install it.")
+  }
 
   vc <- ordinal::VarCorr(x)
   any(sapply(vc, function(.x) any(abs(diag(.x)) < tolerance)))
 }
 
+
+
 #' @export
 check_singularity.MixMod <- function(x, tolerance = 1e-5, ...) {
   any(sapply(diag(x$D), function(.x) any(abs(.x) < tolerance)))
 }
 
+
+
 #' @importFrom stats na.omit
 #' @export
 check_singularity.lme <- function(x, tolerance = 1e-5, ...) {
-  if (!requireNamespace("nlme", quietly = TRUE))
+  if (!requireNamespace("nlme", quietly = TRUE)) {
     stop("Package `nlme` needed for this function to work. Please install it.")
+  }
 
   any(abs(stats::na.omit(as.numeric(diag(nlme::getVarCov(x)))) < tolerance))
 }
 
+
+
 #' @export
 check_singularity.default <- function(x, ...) {
   FALSE
 }
 
 
+
+
+
+
 .collapse_cond <- function(x) {
   if (is.list(x) && "cond" %in% names(x)) {
     x[["cond"]]
   } else {
     x
   }
-}
\ No newline at end of file
+}
