@@ -24,14 +24,15 @@
 #' data(Salamanders)
 #' m <- glm(count ~ spp + mined, family = poisson, data = Salamanders)
 #' check_zeroinflation(m)
-#'
-#' @importFrom insight get_response
-#' @importFrom stats fitted dpois family
+#' @importFrom insight get_response model_info
+#' @importFrom stats fitted dpois
 #' @export
 check_zeroinflation <- function(x, tolerance = .05) {
   # check if we have poisson
-  if (!stats::family(x)$family %in% c("poisson", "quasipoisson"))
+  model_info <- insight::model_info(x)
+  if (!model_info$is_poisson) {
     stop("Model must be from Poisson-family.", call. = F)
+  }
 
   # get actual zero of response
   obs.zero <- sum(insight::get_response(x) == 0)
