@@ -2,9 +2,10 @@
 #'
 #' Compute indices of model performance for mixed models.
 #'
-#' @param model Object of class \code{merMod}, \code{glmmTMB}, \code{lme} or \code{MixMod}.
 #' @param metrics Can be \code{"all"} or a character vector of metrics to be computed (some of \code{c("AIC", "BIC", "R2", "ICC", "RMSE", "LOGLOSS", "SCORE")}).
 #' @param ... Arguments passed to or from other methods.
+#' @inheritParams r2_nakagawa
+#' @inheritParams model_performance.lm
 #'
 #' @return A data frame (with one row) and one column per "index" (see \code{metrics}).
 #'
@@ -19,11 +20,9 @@
 #' library(lme4)
 #' model <- lmer(Petal.Length ~ Sepal.Length + (1 | Species), data = iris)
 #' model_performance(model)
-#'
 #' @importFrom insight model_info
-#' @importFrom stats AIC BIC
 #' @export
-model_performance.merMod <- function(model, metrics = "all", ...) {
+model_performance.merMod <- function(model, metrics = "all", verbose = TRUE, ...) {
   if (all(metrics == "all")) {
     metrics <- c("AIC", "BIC", "R2", "ICC", "RMSE", "LOGLOSS", "SCORE")
   }
@@ -32,10 +31,10 @@ model_performance.merMod <- function(model, metrics = "all", ...) {
 
   out <- list()
   if ("AIC" %in% metrics) {
-    out$AIC <- stats::AIC(model)
+    out$AIC <- .get_AIC(model)
   }
   if ("BIC" %in% metrics) {
-    out$BIC <- stats::BIC(model)
+    out$BIC <- .get_BIC(model)
   }
   if ("R2" %in% metrics) {
     rsq <- suppressWarnings(r2(model))
@@ -46,13 +45,13 @@ model_performance.merMod <- function(model, metrics = "all", ...) {
     if (!all(is.na(icc_mm))) out$ICC <- icc_mm$ICC_adjusted
   }
   if ("RMSE" %in% metrics) {
-    out$RMSE <- performance_rmse(model)
+    out$RMSE <- performance_rmse(model, verbose = verbose)
   }
   if (("LOGLOSS" %in% metrics) && mi$is_binomial) {
-    out$LOGLOSS <- performance_logloss(model)
+    out$LOGLOSS <- performance_logloss(model, verbose = verbose)
   }
   if (("SCORE" %in% metrics) && (mi$is_binomial || mi$is_count)) {
-    .scoring_rules <- performance_score(model)
+    .scoring_rules <- performance_score(model, verbose = verbose)
     if (!is.na(.scoring_rules$logarithmic)) out$SCORE_LOG <- .scoring_rules$logarithmic
     if (!is.na(.scoring_rules$spherical)) out$SCORE_SPHERICAL <- .scoring_rules$spherical
   }
@@ -69,6 +68,12 @@ model_performance.merMod <- function(model, metrics = "all", ...) {
 #' @export
 model_performance.lme <- model_performance.merMod
 
+#' @export
+model_performance.glmmadmb <- model_performance.merMod
+
+#' @export
+model_performance.rlmerMod <- model_performance.merMod
+
 #' @export
 model_performance.MixMod <- model_performance.merMod
 
@@ -76,4 +81,4 @@ model_performance.MixMod <- model_performance.merMod
 model_performance.mixed <- model_performance.merMod
 
 #' @export
-model_performance.glmmTMB <- model_performance.merMod
\ No newline at end of file
+model_performance.glmmTMB <- model_performance.merMod
