@@ -19,7 +19,6 @@
 #' m <- lm(mpg ~ wt + cyl + gear + disp, data = mtcars)
 #' AIC(m)
 #' performance_aicc(m)
-#'
 #' @export
 performance_aicc <- function(x, ...) {
   UseMethod("performance_aicc")
@@ -36,3 +35,13 @@ performance_aicc.default <- function(x, ...) {
 
   -2 * as.vector(ll) + 2 * k * (n / (n - k - 1))
 }
+
+
+#' @export
+performance_aicc.vglm <- function(x, ...) {
+  if (!requireNamespace("VGAM", quietly = TRUE)) {
+    warning("Package 'VGAM' required for this function work. Please install it.", call. = FALSE)
+    return(NULL)
+  }
+  VGAM::AICc(x)
+}
